import type { SafeEquals } from "../../types/SafeEquals.js";
import type { SafeFrom } from "../../types/SafeFrom.js";
import { Character } from "../Character/Character.js";
import { CharacterVarying } from "../Character/CharacterVarying.js";
import { Name } from "../Character/Name.js";
import { Text } from "../Character/Text.js";
import { Int2 } from "../Numeric/Int2.js";
import { Int4 } from "../Numeric/Int4.js";
import { Int8 } from "../Numeric/Int8.js";
import { OID } from "../ObjectIdentifier/OID.js";
import { Bit } from "./Bit.js";
interface BitVaryingObject {
    value: string;
}
interface BitVarying<N extends number> {
    bitVarying: string;
    value: string;
    postgres: string;
    get n(): N;
    toString(): string;
    toNumber(): number;
    toJSON(): BitVaryingObject;
    equals(string: string): boolean;
    equals(number: number): boolean;
    equals(object: Bit<number> | BitVarying<number> | Character<number> | CharacterVarying<number> | Name | Text | Int2 | Int4 | Int8 | OID | BitVaryingObject): boolean;
    safeEquals(string: string): SafeEquals<BitVarying<N>>;
    safeEquals(number: number): SafeEquals<BitVarying<N>>;
    safeEquals(object: Bit<number> | BitVarying<number> | Character<number> | CharacterVarying<number> | Name | Text | Int2 | Int4 | Int8 | OID | BitVaryingObject): SafeEquals<BitVarying<N>>;
}
interface BitVaryingConstructor<N extends number> {
    from(string: string): BitVarying<N>;
    from(number: number): BitVarying<N>;
    from(object: Bit<number> | BitVarying<number> | Character<number> | CharacterVarying<number> | Name | Text | Int2 | Int4 | Int8 | OID | BitVaryingObject): BitVarying<N>;
    safeFrom(string: string): SafeFrom<BitVarying<N>>;
    safeFrom(number: number): SafeFrom<BitVarying<N>>;
    safeFrom(object: Bit<number> | BitVarying<number> | Character<number> | CharacterVarying<number> | Name | Text | Int2 | Int4 | Int8 | OID | BitVaryingObject): SafeFrom<BitVarying<N>>;
    /**
     * Returns `true` if `object` is a `BitVarying`, `false` otherwise.
     */
    isBitVarying(object: any): object is BitVarying<N>;
    /**
     * Returns `true` if `object` is a `BitVarying<N>`, `false` otherwise.
     */
    isBitVarying<N extends number = number>(object: any, n: N): object is BitVarying<N>;
    /**
     * Returns `true` if `object` is a `BitVarying<N>`, `false` otherwise.
     */
    isAnyBitVarying(object: any): object is BitVarying<number>;
    /**
     * Get a `BitVarying` constructor for a specific `n`.
     * @param n The number of bits.
     */
    setN<N extends number = number>(n: N): BitVaryingConstructor<N>;
    /**
     * Get the `n` value for this `BitVarying` constructor.
     * @returns The `n` value.
     */
    get n(): N;
}
declare const BitVarying: BitVaryingConstructor<number>;
export { BitVarying, BitVaryingConstructor, BitVaryingObject };
