import { type ParseReturnType } from "@postgresql-typed/util";
import type { ParseContext } from "../../types/ParseContext.js";
import type { SafeEquals } from "../../types/SafeEquals.js";
import type { SafeFrom } from "../../types/SafeFrom.js";
import { PgTPConstructorBase } from "../../util/PgTPConstructorBase.js";
import { Character } from "../Character/Character.js";
import { CharacterVarying } from "../Character/CharacterVarying.js";
import { Name } from "../Character/Name.js";
import { Text } from "../Character/Text.js";
import { UUID } from "../UUID/UUID.js";
interface EnumObject {
    value: string;
}
interface Enum<EnumValues extends string, Enums extends Readonly<[EnumValues, ...EnumValues[]]>> {
    enum: string;
    value: string;
    postgres: string;
    get enums(): Enums;
    toString(): string;
    toJSON(): EnumObject;
    equals(string: string): boolean;
    equals(object: Character<number> | CharacterVarying<number> | Enum<string, [string, ...string[]]> | Name | Text | UUID | EnumObject): boolean;
    safeEquals(string: string): SafeEquals<Enum<EnumValues, Enums>>;
    safeEquals(object: Character<number> | CharacterVarying<number> | Enum<string, [string, ...string[]]> | Name | Text | UUID | EnumObject): SafeEquals<Enum<EnumValues, Enums>>;
}
interface EnumConstructor<EnumValues extends string, Enums extends Readonly<[EnumValues, ...EnumValues[]]>> {
    from(string: string): Enum<EnumValues, Enums>;
    from(object: Character<number> | CharacterVarying<number> | Enum<string, [string, ...string[]]> | Name | Text | UUID | EnumObject): Enum<EnumValues, Enums>;
    safeFrom(string: string): SafeFrom<Enum<EnumValues, Enums>>;
    safeFrom(object: Character<number> | CharacterVarying<number> | Enum<string, [string, ...string[]]> | Name | Text | UUID | EnumObject): SafeFrom<Enum<EnumValues, Enums>>;
    /**
     * Returns `true` if `object` is a `Enum`, `false` otherwise.
     */
    isEnum(object: any): object is Enum<EnumValues, Enums>;
    /**
     * Returns `true` if `object` is a `Enum<EnumValues,Enums>`, `false` otherwise.
     */
    isEnum<EEnumValues extends string, EEnums extends Readonly<[EEnumValues, ...EEnumValues[]]>>(object: any, enums: EEnums): object is Enum<EEnumValues, EEnums>;
    /**
     * Returns `true` if `object` is a `Enum<string>`, `false` otherwise.
     */
    isAnyEnum(object: any): object is Enum<string, [string, ...string[]]>;
    /**
     * Get a `Enum` constructor for a specific `n`.
     * @param enums An array of strings representing the enum values.
     */
    setEnums<EEnumValues extends string, EEnums extends Readonly<[EEnumValues, ...EEnumValues[]]>>(enums: EEnums): EnumConstructor<EEnumValues, EEnums>;
    /**
     * Get the `Enums` value for this `Enum` constructor.
     * @returns The `Enums` value.
     */
    get enums(): Enums;
}
declare class EnumConstructorClass<EnumValues extends string, Enums extends Readonly<[EnumValues, ...EnumValues[]]>> extends PgTPConstructorBase<Enum<EnumValues, Enums>> implements EnumConstructor<EnumValues, Enums> {
    private _enums;
    constructor(_enums: Enums);
    _parse(context: ParseContext): ParseReturnType<Enum<EnumValues, Enums>>;
    private _parseString;
    private _parseObject;
    isEnum(object: any): object is Enum<EnumValues, Enums>;
    isEnum<EEnumValues extends string, EEnums extends Readonly<[EEnumValues, ...EEnumValues[]]>>(object: any, enums: EEnums): object is Enum<EEnumValues, EEnums>;
    isAnyEnum(object: any): object is Enum<string, [string, ...string[]]>;
    setEnums<EEnumValues extends string, EEnums extends readonly [EEnumValues, ...EEnumValues[]]>(enums: EEnums): EnumConstructor<EEnumValues, EEnums>;
    get enums(): Enums;
}
declare const Enum: EnumConstructorClass<string, ["No", "Enums", "Setupped", "Yet"]>;
export { Enum, EnumConstructor, EnumObject };
