import type { SafeEquals } from "../../types/SafeEquals.js";
import type { SafeFrom } from "../../types/SafeFrom.js";
interface JSONObject {
    value: string;
}
interface JSON {
    json: Record<string, unknown> | unknown[] | string | number | boolean | null;
    value: string;
    postgres: string;
    toString(): string;
    toJSON(): JSONObject;
    equals(record: Record<string, unknown>): boolean;
    equals(array: unknown[]): boolean;
    equals(type: string | number | boolean | null): boolean;
    equals(object: JSON | JSONObject): boolean;
    safeEquals(record: Record<string, unknown>): SafeEquals<JSON>;
    safeEquals(array: unknown[]): SafeEquals<JSON>;
    safeEquals(type: string | number | boolean | null): SafeEquals<JSON>;
    safeEquals(object: JSON | JSONObject): SafeEquals<JSON>;
}
interface JSONConstructor {
    from(record: Record<string, unknown>): JSON;
    from(array: unknown[]): JSON;
    from(type: string | number | boolean | null): JSON;
    from(object: JSON | JSONObject): JSON;
    safeFrom(record: Record<string, unknown>): SafeFrom<JSON>;
    safeFrom(array: unknown[]): SafeFrom<JSON>;
    safeFrom(type: string | number | boolean | null): SafeFrom<JSON>;
    safeFrom(object: JSON | JSONObject): SafeFrom<JSON>;
    /**
     * Returns `true` if `object` is a `JSON`, `false` otherwise.
     */
    isJSON(object: any): object is JSON;
}
declare const JSON: JSONConstructor;
export { JSON, JSONConstructor, JSONObject };
