import type { SafeEquals } from "../types/SafeEquals.js";
import type { SafeFrom } from "../types/SafeFrom.js";
import { Range, RawRangeObject } from "./Range.js";
interface MultiRangeObject<DataType, DataTypeObject> {
    ranges: Range<DataType, DataTypeObject>[];
}
interface RawMultiRangeObject<DataTypeObject> {
    ranges: RawRangeObject<DataTypeObject>[];
}
interface MultiRange<DataType, DataTypeObject> {
    ranges: Range<DataType, DataTypeObject>[];
    value: string;
    postgres: string;
    toString(): string;
    toJSON(): RawMultiRangeObject<DataTypeObject>;
    equals(string: string): boolean;
    equals(range: Range<DataType, DataTypeObject>, ...ranges: Range<DataType, DataTypeObject>[]): boolean;
    equals(ranges: Range<DataType, DataTypeObject>[]): boolean;
    equals(multiRange: MultiRange<DataType, DataTypeObject>): boolean;
    equals(data: MultiRangeObject<DataType, DataTypeObject> | RawMultiRangeObject<DataTypeObject>): boolean;
    safeEquals(string: string): SafeEquals<MultiRange<DataType, DataTypeObject>>;
    safeEquals(range: Range<DataType, DataTypeObject>, ...ranges: Range<DataType, DataTypeObject>[]): SafeEquals<MultiRange<DataType, DataTypeObject>>;
    safeEquals(ranges: Range<DataType, DataTypeObject>[]): SafeEquals<MultiRange<DataType, DataTypeObject>>;
    safeEquals(multiRange: MultiRange<DataType, DataTypeObject>): SafeEquals<MultiRange<DataType, DataTypeObject>>;
    safeEquals(data: MultiRangeObject<DataType, DataTypeObject> | RawMultiRangeObject<DataTypeObject>): SafeEquals<MultiRange<DataType, DataTypeObject>>;
}
interface MultiRangeConstructor<DataType, DataTypeObject> {
    from(string: string): MultiRange<DataType, DataTypeObject>;
    from(range: Range<DataType, DataTypeObject>, ...ranges: Range<DataType, DataTypeObject>[]): MultiRange<DataType, DataTypeObject>;
    from(ranges: Range<DataType, DataTypeObject>[]): MultiRange<DataType, DataTypeObject>;
    from(multiRange: MultiRange<DataType, DataTypeObject>): MultiRange<DataType, DataTypeObject>;
    from(data: MultiRangeObject<DataType, DataTypeObject> | RawMultiRangeObject<DataTypeObject>): MultiRange<DataType, DataTypeObject>;
    safeFrom(string: string): SafeFrom<MultiRange<DataType, DataTypeObject>>;
    safeFrom(range: Range<DataType, DataTypeObject>, ...ranges: Range<DataType, DataTypeObject>[]): SafeFrom<MultiRange<DataType, DataTypeObject>>;
    safeFrom(ranges: Range<DataType, DataTypeObject>[]): SafeFrom<MultiRange<DataType, DataTypeObject>>;
    safeFrom(multiRange: MultiRange<DataType, DataTypeObject>): SafeFrom<MultiRange<DataType, DataTypeObject>>;
    safeFrom(data: MultiRangeObject<DataType, DataTypeObject> | RawMultiRangeObject<DataTypeObject>): SafeFrom<MultiRange<DataType, DataTypeObject>>;
    /**
     * Returns `true` if `object` is a `MultiRange` of the same type as `this`, `false` otherwise.
     */
    isMultiRange(object: any): object is MultiRange<DataType, DataTypeObject>;
}
declare const getMultiRange: <DataType extends {
    equals(other: DataType): boolean;
    toString(): string;
    toJSON(): DataTypeObject;
}, DataTypeObject>(object: any, isObjectFunction: (object: any) => object is Range<DataType, DataTypeObject>, identifier: string) => MultiRangeConstructor<DataType, DataTypeObject>;
export { getMultiRange, MultiRange, MultiRangeConstructor, MultiRangeObject, RawMultiRangeObject };
