/* eslint-disable unicorn/filename-case */
import { isValid } from "@postgresql-typed/util";
import { getErrorMap } from "./errorMap.js";
import { PgTPError } from "./PgTPError.js";
export class PgTPBase {
    constructor() {
        this.equals = this.equals.bind(this);
        this.safeEquals = this.safeEquals.bind(this);
    }
    equals(...data) {
        const result = this.safeEquals(...data);
        if (result.success)
            return result.equals;
        throw result.error;
    }
    safeEquals(...data) {
        const context = {
            issue: null,
            errorMap: getErrorMap(),
            data,
        }, result = this._equals(context);
        return this._handleResult(context, result);
    }
    _handleResult(context, result) {
        if (isValid(result)) {
            return {
                success: true,
                equals: result.value.equals,
                data: result.value.data,
            };
        }
        if (!context.issue)
            throw new Error("Validation failed but no issue detected.");
        const error = new PgTPError(context.issue);
        return { success: false, error };
    }
    setIssueForContext(context, issueData) {
        context.issue = {
            ...issueData,
            message: context.errorMap(issueData).message,
        };
    }
}
//# sourceMappingURL=PgTPBase.js.map